@@ -8,10 +8,8 @@
  *    4. Unit tests.
  *    5. Test driver.
  *    6. Example.
- *    7. Copyright and license information.
  *    
  * SRE, Fri Aug 15 08:02:43 2008 [Janelia]
- * SVN $Id: stotrace.c 3018 2009-10-29 17:33:06Z farrarm $
  */   
 #include "p7_config.h"
 
@@ -259,18 +257,15 @@ select_j(ESL_RANDOMNESS *rng, const P7_OPROFILE *om, const P7_OMX *ox, int i)
 static inline int
 select_e(ESL_RANDOMNESS *rng, const P7_OPROFILE *om, const P7_OMX *ox, int i, int *ret_k)
 {
-  int    Q     = p7O_NQF(ox->M);
-  float  sum   = 0.0;
-  float  roll  = esl_random(rng);
-  float  norm  = 1.0 / ox->xmx[i*p7X_NXCELLS+p7X_E]; /* all M, D already scaled exactly the same */
-  vector float xEv;
-  vector float zerov;
+  int          Q     = p7O_NQF(ox->M);
+  double       sum   = 0.0;
+  double       roll  = esl_random(rng);
+  double       norm  = 1.0 / ox->xmx[i*p7X_NXCELLS+p7X_E];   /* all M, D already scaled exactly the same */
+  vector float xEv   = esl_vmx_set_float(norm);
+  vector float zerov = (vector float) vec_splat_u32(0);
   union { vector float v; float p[4]; } u;
   int    q,r;
 
-  xEv = esl_vmx_set_float(norm);
-  zerov = (vector float) vec_splat_u32(0);
-
   while (1) {
     for (q = 0; q < Q; q++)
       {
@@ -286,8 +281,7 @@ select_e(ESL_RANDOMNESS *rng, const P7_OPROFILE *om, const P7_OMX *ox, int i, in
 	  if (roll < sum) { *ret_k = r*Q + q + 1; return p7T_D;}
 	}
       }
-    if (sum < 0.99) 
-      ESL_EXCEPTION(-1, "Probabilities weren't normalized - failed to trace back from an E");
+    ESL_DASSERT1(sum > 0.99);
   }
   /*UNREACHED*/
   ESL_EXCEPTION(-1, "unreached code was reached. universe collapses.");
@@ -341,7 +335,7 @@ static char banner[] = "benchmark driver for stochastic traceback, VMX version";
 int 
 main(int argc, char **argv)
 {
-  ESL_GETOPTS    *go      = esl_getopts_CreateDefaultApp(options, 1, argc, argv, banner, usage);
+  ESL_GETOPTS    *go      = p7_CreateDefaultApp(options, 1, argc, argv, banner, usage);
   char           *hmmfile = esl_opt_GetArg(go, 1);
   ESL_STOPWATCH  *w       = esl_stopwatch_Create();
   ESL_RANDOMNESS *r       = esl_randomness_CreateFast(esl_opt_GetInteger(go, "-s"));
@@ -361,8 +355,8 @@ main(int argc, char **argv)
   float           sc, fsc, vsc;
   float           bestsc  = -eslINFINITY;
   
-  if (p7_hmmfile_Open(hmmfile, NULL, &hfp) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)     != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
 
   bg = p7_bg_Create(abc);                p7_bg_SetLength(bg, L);
   gm = p7_profile_Create(hmm->M, abc);   p7_ProfileConfig(hmm, bg, gm, L, p7_UNILOCAL);
@@ -489,7 +483,7 @@ static char banner[] = "unit test driver for stochastic Viterbi traceback (gener
 int
 main(int argc, char **argv)
 {
-  ESL_GETOPTS    *go     = esl_getopts_CreateDefaultApp(options, 0, argc, argv, banner, usage);
+  ESL_GETOPTS    *go     = p7_CreateDefaultApp(options, 0, argc, argv, banner, usage);
   ESL_RANDOMNESS *r      = esl_randomness_CreateFast(esl_opt_GetInteger(go, "-s"));
   ESL_ALPHABET   *abc    = NULL;
   P7_HMM         *hmm    = NULL;
@@ -571,7 +565,7 @@ static char banner[] = "example of stochastic backtrace (VMX version)";
 int 
 main(int argc, char **argv)
 {
-  ESL_GETOPTS    *go      = esl_getopts_CreateDefaultApp(options, 2, argc, argv, banner, usage);
+  ESL_GETOPTS    *go      = p7_CreateDefaultApp(options, 2, argc, argv, banner, usage);
   char           *hmmfile = esl_opt_GetArg(go, 1);
   char           *seqfile = esl_opt_GetArg(go, 2);
   ESL_ALPHABET   *abc     = NULL;
@@ -594,8 +588,8 @@ main(int argc, char **argv)
   int             status;
 
   /* Read in one HMM */
-  if (p7_hmmfile_Open(hmmfile, NULL, &hfp) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
-  if (p7_hmmfile_Read(hfp, &abc, &hmm)     != eslOK) p7_Fail("Failed to read HMM");
+  if (p7_hmmfile_OpenE(hmmfile, NULL, &hfp, NULL) != eslOK) p7_Fail("Failed to open HMM file %s", hmmfile);
+  if (p7_hmmfile_Read(hfp, &abc, &hmm)            != eslOK) p7_Fail("Failed to read HMM");
 
   /* Read in one sequence */
   sq     = esl_sq_CreateDigital(abc);
@@ -654,13 +648,3 @@ main(int argc, char **argv)
 #endif /*p7STOTRACE_EXAMPLE*/
 /*------------------------ end, example -------------------------*/
 
-
-/*****************************************************************
- * HMMER - Biological sequence analysis with profile HMMs
- * Version 3.0; March 2010
- * Copyright (C) 2010 Howard Hughes Medical Institute.
- * Other copyrights also apply. See the COPYRIGHT file for a full list.
- * 
- * HMMER is distributed under the terms of the GNU General Public License
- * (GPLv3). See the LICENSE file for details.
- *****************************************************************/
